*====================================================================================================*
*                                  analysis.do                                                       *
*====================================================================================================*

*----------------------------------------------------------------------------------------------------*
*  Leopold & Schulz 2018, replication files                                               			 *
*  last update: 08 March 2018                                                                        *
*  data: soeplong 1984-2015, version 32.1, release 2017                                              *
*----------------------------------------------------------------------------------------------------*


* Load prepared data

use "$posted/data", clear


* Table 1

tab srh_w, gen(w)
tab srh_h, gen(h)
sum age_w age_h w? h? hw_w hws_w hw_h hws_h rep_w reps_w rep_h reps_h out



* Models

xtset cid syear


* Wife's routine housework

xtreg hw_w i.srh_w i.srh_h i.cage_w, fe
est store M1
margins srh_w, atmeans post vsquish noestimcheck
est store ww

rename srh_w aux
rename srh_h srh_w
label values srh_w h

xtreg hw_w i.srh_w i.aux i.cage_w, fe
margins srh_w, atmeans post vsquish noestimcheck
est store wh

rename srh_w srh_h
rename aux srh_w
label values srh_w h


coefplot ///
		(ww, label(Wife's health) offset(-0.05) msymbol(O) 									///
			mcolor(black) lcolor(black) lwidth(medthick) lcolor(black) ciopts(lcol(black))) ///		
		(wh, label(Husband's health) offset(0.05) msymbol(D)								///
			mcolor(gs9)  lcolor(gs9)  lwidth(medthick) lcolor(gs9) ciopts(lcol(gs9))) 		///		
	, title 	("Wife's Hours of Routine Tasks", size(medium) col(black)) 					///
				vertical recast(connected)  												///
				ytitle("Hours on a typical weekday", size(small)) 							///
				yscale(titlegap(2))															///
				ylab (4 (0.25) 2.5, labsize(small) angle(0)) 								///
				xtitle("Self-rated health", size(small)) 									///
				xlab (, labsize(small)) xscale(titlegap(2))									///
				legend(title("", size(small) col(black)) size(small) rows(1)) 				///
				graphregion(color(white) fcolor(white) icolor(white)) 						///
	name (fig1a, replace)	


* Husband's routine housework

xtreg hw_h i.srh_w i.srh_h i.cage_h, fe
est store M2
margins srh_w, atmeans post vsquish noestimcheck
est store hw

rename srh_w aux
rename srh_h srh_w
label values srh_w h

xtreg hw_h i.srh_w i.aux i.cage_h, fe
margins srh_w, atmeans post vsquish noestimcheck
est store hh

rename srh_w srh_h
rename aux srh_w
label values srh_w h


coefplot ///
		(hw, label(Wife's health) offset(-0.05) msymbol(O) 									///
			mcolor(black) lcolor(black) lwidth(medthick) lcolor(black) ciopts(lcol(black))) ///		
		(hh, label(Husband's health) offset(0.05) msymbol(D)								///
			mcolor(gs9)  lcolor(gs9)  lwidth(medthick) lcolor(gs9) ciopts(lcol(gs9))) 		///		
	, title 	("Husband's Hours of Routine Tasks", size(medium) col(black)) 				///
				vertical recast(connected)  												///
				ytitle("Hours on a typical weekday", size(small)) 							///
				yscale(titlegap(2))															///
				ylab (1.5 (0.25) 0, labsize(small) angle(0)) 								///
				xtitle("Self-rated health", size(small)) 									///
				xlab (, labsize(small)) xscale(titlegap(2))									///
				legend(title("", size(small) col(black)) size(small) rows(1)) 				///	
				graphregion(color(white) fcolor(white) icolor(white)) 						///
	name (fig1b, replace)	
	

* Wife's repairs

xtreg rep_w i.srh_w i.srh_h i.cage_w, fe
est store M5
margins srh_w, atmeans post vsquish noestimcheck
est store ww

rename srh_w aux
rename srh_h srh_w
label values srh_w h

xtreg rep_w i.srh_w i.aux i.cage_w, fe
margins srh_w, atmeans post vsquish noestimcheck
est store wh

rename srh_w srh_h
rename aux srh_w
label values srh_w h


coefplot ///
		(ww, label(Wife's health) offset(-0.05) msymbol(O) 									///
			mcolor(black) lcolor(black) lwidth(medthick) lcolor(black) ciopts(lcol(black))) ///		
		(wh, label(Husband's health) offset(0.05) msymbol(D)								///
			mcolor(gs9)  lcolor(gs9)  lwidth(medthick) lcolor(gs9) ciopts(lcol(gs9))) 		///		
	, title 	("Wife's Hours of Non-Routine Tasks", size(medium) col(black)) 				///
				vertical recast(connected)  												///
				ytitle("Hours on a typical weekday", size(small)) 							///
				ylab (2.2 (0.25) 0.7, labsize(small) angle(0)) 								///
				yscale(titlegap(2))															///
				xtitle("Self-rated health", size(small)) 									///
				xlab (, labsize(small)) xscale(titlegap(2))									///
				legend(title("", size(small) col(black)) size(small) rows(1)) 				///
				graphregion(color(white) fcolor(white) icolor(white)) 						///
	name (fig2a, replace)	


* Husband's repairs

xtreg rep_h i.srh_w i.srh_h i.cage_h, fe
est store M6
margins srh_w, atmeans post vsquish noestimcheck
est store hw

rename srh_w aux
rename srh_h srh_w
label values srh_w h

xtreg rep_h i.srh_w i.aux i.cage_h, fe
margins srh_w, atmeans post vsquish noestimcheck
est store hh

rename srh_w srh_h
rename aux srh_w
label values srh_w h


coefplot ///
		(hw, label(Wife's health) offset(-0.05) msymbol(O) 									///
			mcolor(black) lcolor(black) lwidth(medthick) lcolor(black) ciopts(lcol(black))) ///		
		(hh, label(Husband's health) offset(0.05) msymbol(D)								///
			mcolor(gs9)  lcolor(gs9)  lwidth(medthick) lcolor(gs9) ciopts(lcol(gs9))) 		///		
	, title 	("Husband's Hours of Non-Routine Tasks", size(medium) col(black)) 			///
				vertical recast(connected)  												///
				ytitle("Hours on a typical weekday", size(small)) 							///
				yscale(titlegap(2))															///
				ylab (2.2 (0.25) 0.7, labsize(small) angle(0)) 								///
				xtitle("Self-rated health", size(small)) 									///
				xlab (, labsize(small)) xscale(titlegap(2))									///
				legend(title("", size(small) col(black)) size(small) rows(1)) 				///
				graphregion(color(white) fcolor(white) icolor(white)) 						///
	name (fig2b, replace)	
	

* Wife's share of routine housework

xtreg hws_w c.hw_c i.srh_w i.srh_h i.cage_w, fe
est store M3
margins srh_w, atmeans post vsquish noestimcheck
est store sww

rename srh_w aux
rename srh_h srh_w
label values srh_w h

xtreg hws_w c.hw_c i.srh_w i.aux i.cage_w, fe
margins srh_w, atmeans post vsquish noestimcheck
est store swh

rename srh_w srh_h
rename aux srh_w
label values srh_w h


coefplot ///
		(sww, label(Wife's health) offset(-0.05) msymbol(O) 								///
			mcolor(black) lcolor(black) lwidth(medthick) lcolor(black) ciopts(lcol(black))) ///		
		(swh, label(Husband's health) offset(0.05) msymbol(D)								///
			mcolor(gs9)  lcolor(gs9)  lwidth(medthick) lcolor(gs9) ciopts(lcol(gs9))) 		///		
	, title 	("Wife's Share of Routine Tasks", size(medium) col(black)) 					///
				vertical recast(connected)  												///
				ytitle("Percentage share", size(small)) 									///
				yscale(titlegap(2))															///
				ylab (0.9 (0.05) 0.6, labsize(small) angle(0)) 								///
				xtitle("Self-rated health", size(small)) 									///
				xlab (, labsize(small)) xscale(titlegap(2))									///
				legend(title("", size(small) col(black)) size(small) rows(1)) 				///
				graphregion(color(white) fcolor(white) icolor(white)) 						///
	name (fig1c, replace)	
	

* Husband's share of routine housework

xtreg hws_h c.hw_c i.srh_w i.srh_h i.cage_h, fe
est store M4
margins srh_w, atmeans post vsquish noestimcheck
est store shw

rename srh_w aux
rename srh_h srh_w
label values srh_w h

xtreg hws_h c.hw_c i.srh_w i.aux i.cage_h, fe
margins srh_w, atmeans post vsquish noestimcheck
est store shh

rename srh_w srh_h
rename aux srh_w
label values srh_w h


coefplot ///
		(shw, label(Wife's health) offset(-0.05) msymbol(O) 								///
			mcolor(black) lcolor(black) lwidth(medthick) lcolor(black) ciopts(lcol(black))) ///		
		(shh, label(Husband's health) offset(0.05) msymbol(D)								///
			mcolor(gs9)  lcolor(gs9)  lwidth(medthick) lcolor(gs9) ciopts(lcol(gs9))) 		///		
	, title 	("Husband's Share of Routine Tasks", size(medium) col(black)) 				///
				vertical recast(connected)  												///
				ytitle("Percentage share", size(small)) 									///
				yscale(titlegap(2))															///
				ylab (0.4 (0.05) 0.1, labsize(small) angle(0)) 								///
				xtitle("Self-rated health", size(small)) 									///
				xlab (, labsize(small)) xscale(titlegap(2))									///
				legend(title("", size(small) col(black)) size(small) rows(1)) 				///
				graphregion(color(white) fcolor(white) icolor(white)) 						///
	name (fig1d, replace)	

	
* Figure 1
grc1leg2 fig1a fig1b fig1c fig1d, graphregion(color(white))
graph export "$graphs\figure1.pdf", replace



* Wife's share of repairs

xtreg reps_w c.hw_c i.srh_w i.srh_h i.cage_w, fe
est store M7
margins srh_w, atmeans post vsquish noestimcheck
est store sww

rename srh_w aux
rename srh_h srh_w
label values srh_w h

xtreg reps_w c.hw_c i.srh_w i.aux i.cage_w, fe
margins srh_w, atmeans post vsquish noestimcheck
est store swh

rename srh_w srh_h
rename aux srh_w
label values srh_w h


coefplot ///
		(sww, label(Wife's health) offset(-0.05) msymbol(O) 								///
			mcolor(black) lcolor(black) lwidth(medthick) lcolor(black) ciopts(lcol(black))) ///		
		(swh, label(Husband's health) offset(0.05) msymbol(D)								///
			mcolor(gs9)  lcolor(gs9)  lwidth(medthick) lcolor(gs9) ciopts(lcol(gs9))) 		///		
	, title 	("Wife's Share of Non-Routine Tasks", size(medium) col(black)) 				///
				vertical recast(connected)  												///
				ytitle("Percentage share", size(small)) 									///
				yscale(titlegap(2))															///
				ylab (0.5 (0.05) 0.2, labsize(small) angle(0)) 								///
				xtitle("Self-rated health", size(small)) 									///
				xlab (, labsize(small)) xscale(titlegap(2))									///
				legend(title("", size(small) col(black)) size(small) rows(1)) 				///
				graphregion(color(white) fcolor(white) icolor(white)) 						///
	name (fig2c, replace)	
	


* Husband's share of repairs

xtreg reps_h c.hw_c i.srh_w i.srh_h i.cage_h, fe
est store M8
margins srh_w, atmeans post vsquish noestimcheck
est store shw

rename srh_w aux
rename srh_h srh_w
label values srh_w h

xtreg reps_h c.hw_c i.srh_w i.aux i.cage_h, fe
margins srh_w, atmeans post vsquish noestimcheck
est store shh

rename srh_w srh_h
rename aux srh_w
label values srh_w h


coefplot ///
		(shw, label(Wife's health) offset(-0.05) msymbol(O) 								///
			mcolor(black) lcolor(black) lwidth(medthick) lcolor(black) ciopts(lcol(black))) ///		
		(shh, label(Husband's health) offset(0.05) msymbol(D)								///
			mcolor(gs9)  lcolor(gs9)  lwidth(medthick) lcolor(gs9) ciopts(lcol(gs9))) 		///		
	, title 	("Husband's Share of Non-Routine Tasks", size(medium) col(black)) 			///
				vertical recast(connected)  												///
				ytitle("Percentage share", size(small)) 									///
				yscale(titlegap(2))															///
				ylab (0.8 (0.05) 0.5, labsize(small) angle(0)) 								///
				xtitle("Self-rated health", size(small)) 									///
				xlab (, labsize(small)) xscale(titlegap(2))									///
				legend(title("", size(small) col(black)) size(small) rows(1)) 				///
				graphregion(color(white) fcolor(white) icolor(white)) 						///
	name (fig2d, replace)	

	
* Figure 2
grc1leg2 fig2a fig2b fig2c fig2d, graphregion(color(white))
graph export  "$graphs\figure2.pdf", replace


* Domestic outsourcing

xtreg out i.srh_w i.srh_h i.cage_h, fe
est store M9
margins srh_w, atmeans post vsquish noestimcheck
est store hhw

rename srh_w aux
rename srh_h srh_w
label values srh_w h

xtreg out i.srh_w i.aux i.cage_h, fe
margins srh_w, atmeans post vsquish noestimcheck
est store hhh

rename srh_w srh_h
rename aux srh_w
label values srh_w h


coefplot ///
		(hhw, label(Wife's health) offset(-0.05) msymbol(O) 								///
			mcolor(black) lcolor(black) lwidth(medthick) lcolor(black) ciopts(lcol(black))) ///		
		(hhh, label(Husband's health) offset(0.05) msymbol(D)								///
			mcolor(gs9)  lcolor(gs9)  lwidth(medthick) lcolor(gs9) ciopts(lcol(gs9))) 		///		
	, title 	("Domestic Outsourcing", size(medium) col(black)) 							///
				vertical recast(connected)  												///
				ytitle("Probability of paid household help", size(small)) 					///
				ylab (0.18 (0.01) 0.06, labsize(small) angle(0)) 							///
				xtitle("Self-rated health", size(small)) 									///
				xlab (, labsize(small)) xscale(titlegap(2))									///
				legend(title("", size(small) col(black)) size(small) rows(1)) 				///
				graphregion(color(white) fcolor(white) icolor(white)) 						///
	name (fig3, replace)	
graph export "$graphs\figure3.pdf", replace


* Table 2

outreg2 [M1 M2 M3 M4 M5 M6 M7 M8 M9]  									///
	using "${tables}/table_2", word replace cti(b) dec(2) 				///
	alpha(.001, .01, .05) symbol(***, **, *) noobs drop(*b. 99* *miss)	
	
	
	
*====================================================================================================*
*====================================================================================================*
